==> document_ocr-1.0.12.tar.gz: document_ocr/src/Plugin/document_ocr/processor/Docconv.php <==
<?php

namespace Drupal\document_ocr\Plugin\document_ocr\processor;

use Drupal\Core\Form\FormStateInterface;
use Drupal\document_ocr\Plugin\ProcessorBase;
use Symfony\Component\Process\Exception\ProcessFailedException;
use Symfony\Component\Process\Process;

/**
 * Docconv processor plugin.
 *
 * @DocumentOcrProcessor(
 *   id = "docconv_extractor",
 *   name = @Translation("Docconv Extractor"),
 *   extensions = "pdf doc docx xml html rtf odt pages",
 * )
 */
class Docconv extends ProcessorBase {

  /**
   * {@inheritdoc}
   */
  public function requirementsAreMet() {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function configurationForm(array $form, FormStateInterface $form_state) {
    $configuration = $this->getConfiguration();
    $form['bin_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Command Location'),
      '#default_value' => !empty($configuration['bin_path']) ? $configuration['bin_path'] : '',
      '#description' => $this->t('Set the path to the docd command.'),
      '#placeholder' => $this->t('Example: /usr/bin/docd'),
      '#required' => TRUE,
    ];
    $form['timeout'] = [
      '#type' => 'number',
      '#title' => $this->t('Timeout'),
      '#default_value' => !empty($configuration['timeout']) ? (int) $configuration['timeout'] : 60,
      '#placeholder' => $this->t('Set execution timeout value in seconds. Recommended is 60 seconds.'),
      '#required' => TRUE,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function configurationValues(array &$form, FormStateInterface $form_state) {
    return [
      'bin_path' => $form_state->getValue('bin_path'),
      'timeout' => (int) $form_state->getValue('timeout'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getMappingData() {
    try {
      $configuration = $this->getConfiguration();
      if ($file = $this->getFile()) {
        $process = new Process([$configuration['bin_path'], '-input', $this->fileSystem->realpath($file->getFileUri())]);
        $process->setTimeout($configuration['timeout']);
        $process->run();
        if (!$process->isSuccessful()) {
          throw new ProcessFailedException($process);
        }
        $this->setOption('extracted_text', $this->t('Extracted Text'));
        $this->setOptionValue('extracted_text', $process->getOutput());
        $this->setDocument($process);
      }
      else {
        $this->setOption('extracted_text', $this->t('Extracted Text'));
        $this->setOptionValue('extracted_text', '');
      }
      return $this;
    }
    catch (\Exception $ex) {
      $this->loggerFactory->error($ex->getMessage());
      return FALSE;
    }
  }

}

==> document_ocr-1.0.13.tar.gz: document_ocr/src/Plugin/document_ocr/processor/Docconv.php <==
<?php

namespace Drupal\document_ocr\Plugin\document_ocr\processor;

use Drupal\Core\Form\FormStateInterface;
use Drupal\document_ocr\Plugin\ProcessorBase;
use Symfony\Component\Process\Exception\ProcessFailedException;
use Symfony\Component\Process\Process;

/**
 * Docconv processor plugin.
 *
 * @DocumentOcrProcessor(
 *   id = "docconv_extractor",
 *   name = @Translation("Docconv Extractor"),
 *   extensions = "pdf doc docx xml html rtf odt pages",
 * )
 */
class Docconv extends ProcessorBase {

  /**
   * {@inheritdoc}
   */
  public function requirementsAreMet() {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function configurationForm(array $form, FormStateInterface $form_state) {
    $configuration = $this->getConfiguration();
    $form['bin_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Command Location'),
      '#default_value' => !empty($configuration['bin_path']) ? $configuration['bin_path'] : '',
      '#description' => $this->t('Set the path to the docd command. See <a href="https://github.com/sajari/docconv" target="_blank">details on how to install this utility</a>.'),
      '#placeholder' => $this->t('Example: /usr/bin/docd'),
      '#required' => TRUE,
    ];
    $form['timeout'] = [
      '#type' => 'number',
      '#title' => $this->t('Timeout'),
      '#default_value' => !empty($configuration['timeout']) ? (int) $configuration['timeout'] : 60,
      '#placeholder' => $this->t('Set execution timeout value in seconds. Recommended is 60 seconds.'),
      '#required' => TRUE,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function configurationValues(array &$form, FormStateInterface $form_state) {
    return [
      'bin_path' => $form_state->getValue('bin_path'),
      'timeout' => (int) $form_state->getValue('timeout'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getMappingData() {
    try {
      $configuration = $this->getConfiguration();
      if ($file = $this->getFile()) {
        $process = new Process([$configuration['bin_path'], '-input', $this->fileSystem->realpath($file->getFileUri())]);
        $process->setTimeout($configuration['timeout']);
        $process->run();
        if (!$process->isSuccessful()) {
          throw new ProcessFailedException($process);
        }
        $this->setOption('extracted_text', $this->t('Extracted Text'));
        $this->setOptionValue('extracted_text', $process->getOutput());
        $this->setDocument($process);
      }
      else {
        $this->setOption('extracted_text', $this->t('Extracted Text'));
        $this->setOptionValue('extracted_text', '');
      }
      return $this;
    }
    catch (\Exception $ex) {
      $this->loggerFactory->error($ex->getMessage());
      return FALSE;
    }
  }

}
